.. _glossary:

Glossary
========

.. glossary::
   :sorted:

   Pyramid
      A `Python web framework <http://pylonsproject.org/>`_.

   jQuery Mobile
      A touch-optimized application development framework for smartphones &
      tablets.  See http://jquerymobile.com .

   scaffold
      A parameterized set of files that can be used to generate a Pyramid
      application.

   PhoneGap
      A `framework <http://www.phonegap.com/>`_ which allows HTML5 apps to be
      used as "native" applications on iPhone, Android, and other mobile
      platforms.
